# pytest-html-report-merger
merge html reports generated by the pytest-html plugin

## Try it out

Generate sample test results in the `data/reports` directory:
```bash
make generate-results
```
The output will show some failed tests. This is expected.

Merge the reports:
```bash
make run
```

View the merged report:
```bash
firefox ./data/reports/merged.html
```
